CButtonBaseProps class

Implementers

Constructors

CButtonBaseProps({required bool enable, required CButtonKind kind, required CButtonSize size, required VoidCallback onTap})

Properties

enable → bool
Whether the toggle is enabled or not.
final
hashCode → int
The hash code for this object.
no setterinherited
kind → CButtonKind
The kind that the button represents. It can be primary, secondary, danger, tertiary, ghost.
final
onTap → VoidCallback
Called when the button is tapped.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → CButtonSize
The size of this button. It can be regular, sm, md.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited