CButtonIconOnlyProps class

Inheritance

Constructors

CButtonIconOnlyProps({required Widget icon, required bool enable, required CButtonKind kind, required CButtonSize size, required VoidCallback onTap})

Properties

enable → bool
Whether the toggle is enabled or not.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget
An icon to display in the button.
final
kind → CButtonKind
The kind that the button represents. It can be primary, secondary, danger, tertiary, ghost.
finalinherited
onTap → VoidCallback
Called when the button is tapped.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → CButtonSize
The size of this button. It can be regular, sm, md.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited