CFormProps class

Constructors

CFormProps({required bool enable, required List<Widget> children, required CFormType type, required Widget? action})

Properties

action → Widget?
An action widget to display at the end of the form.
final
children → List<Widget>
The content of the form.
final
enable → bool
Whether the form is enabled or not.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CFormType
The type of the form. It can be group, blank.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited