CLinkProps class

Constructors

CLinkProps({required String? caption, required String url, required double fontSize, required bool enable, required void onTap(String url)})

Properties

caption → String?
A caption text to display instead of the url. If it's null, then the URL will be displayed.
final
enable → bool
Whether the link is enabled or not.
final
fontSize → double
The size of glyphs (in logical pixels) to use when painting the text.
final
hashCode → int
The hash code for this object.
no setterinherited
onTap → void Function(String url)
Called when the link is tapped, it also passes the url value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
The destination that this link leads to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited