CNotificationActionButtonProps class

Constructors

CNotificationActionButtonProps({required Widget child, required VoidCallback onTap, required double? width, required double? height})

Properties

child → Widget
The content of the action button.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
The height of the action button. If it's null, the action button will size itself to the child.
final
onTap → VoidCallback
Called when the action button is tapped.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
The width of the action button. If it's null, the action button will size itself to the child.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited