CNotificationBaseProps class

Implementers

Constructors

CNotificationBaseProps({required Widget title, required Widget subtitle, required bool hideCloseButton, required CNotificationKind kind, required CNotificationContrast contrast, required VoidCallback? onCloseButtonTap, required VoidCallback? onClose, required int? timeout})

Properties

contrast → CNotificationContrast
Whether you are using the low contrast variant of the CNotification.
final
hashCode → int
The hash code for this object.
no setterinherited
hideCloseButton → bool
Whether the close button should be disabled, or not.
final
kind → CNotificationKind
The state that the CNotification represents. It can be error, info, success, or warning.
final
onClose → VoidCallback?
Called after the given timeout duration has passed.
final
onCloseButtonTap → VoidCallback?
Called when the close button is tapped.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → Widget
The subtitle to display.
final
timeout → int?
An optional duration (milliseconds) to determine the amount of time the CNotification should be displayed.
final
title → Widget
The title to display.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited