CNotificationInlineProps class

Inheritance

Constructors

CNotificationInlineProps({required List<CNotificationActionButton>? actions, required Widget title, required Widget subtitle, required bool hideCloseButton, required CNotificationKind kind, required CNotificationContrast contrast, required VoidCallback? onCloseButtonTap, required VoidCallback? onClose, required int? timeout})

Properties

actions → List<CNotificationActionButton>?
A list of CNotificationActionButton to display in a row when the CNotification is inline.
final
contrast → CNotificationContrast
Whether you are using the low contrast variant of the CNotification.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hideCloseButton → bool
Whether the close button should be disabled, or not.
finalinherited
kind → CNotificationKind
The state that the CNotification represents. It can be error, info, success, or warning.
finalinherited
onClose → VoidCallback?
Called after the given timeout duration has passed.
finalinherited
onCloseButtonTap → VoidCallback?
Called when the close button is tapped.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → Widget
The subtitle to display.
finalinherited
timeout → int?
An optional duration (milliseconds) to determine the amount of time the CNotification should be displayed.
finalinherited
title → Widget
The title to display.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited