COverflowMenuButtonProps class

Inheritance

Constructors

COverflowMenuButtonProps({required bool enable, required Widget icon, required List<COverflowMenuItem> items, required Offset menuOffset, required VoidCallback? onClose, required VoidCallback? onOpen, required COverflowMenuSize size, required bool barrierDismissible})

Properties

barrierDismissible → bool
Whether you can close the menu by tapping the barrier.
finalinherited
enable → bool
Whether the button is enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget
The icon of the button.
final
items → List<COverflowMenuItem>
A list of COverflowMenuItem to display in a column when the menu is open.
finalinherited
The adjustment in position applied to the menu.
finalinherited
onClose → VoidCallback?
Called after the menu is closed.
finalinherited
onOpen → VoidCallback?
Called after the menu is open.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → COverflowMenuSize
The size of this menu. It can be regular, sm, or md
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited