CTileProps class

Constructors

CTileProps({required bool enable, required String? label, required String? title, required String? description, required double labelSize, required double titleSize, required double descriptionSize, required Widget? content})

Properties

content → Widget?
final
description → String?
final
descriptionSize → double
final
enable → bool
final
hashCode → int
The hash code for this object.
no setterinherited
label → String?
final
labelSize → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final
titleSize → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited