CToggleProps class

Constructors

CToggleProps({required void onToggle(bool value), required bool enable, required bool value, required String? labelText, required CToggleSize size, required bool showStatusLabel})

Properties

enable → bool
Whether the toggle is enabled or not
final
hashCode → int
The hash code for this object.
no setterinherited
labelText → String?
The labelText of this toggle
final
onToggle → void Function(bool value)
Called when the value of the toggle change.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showStatusLabel → bool
Whether the toggle should display its status (On | Off) or not
final
size → CToggleSize
The size of this toggle. It can be md or sm
final
value → bool
Whether the initial value of the toggle is checked or not.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited